Crate cranium_api

Crate cranium_api 

This crate provides tooling to run Cranium as an “AI Server” for non-Bevy applications (or Bevy applications who want to keep their Worlds separate from the AI World).

This includes functions to create an ECS World, drive it tick-by-tick externally, update the state of the World to keep the AI decisions sane, etc.

Functions

_heartbeat
Triggers AutoRunHeartbeat events, keeping the AutoRun-ing Cranium instance alive. This function is expected to be called periodically by the user from downstream code as an alternative to driving the whole App themselves.
_tick_world
autorun
configure_for_autorun
create_and_autorun
create_app